/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  

  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "../snd.h"
#include "mod-csound-internal.h"

int
_mod_csound_is_music_file (_mod_csound_context_t *
			   csound_context, char *music_file)
{
  int ret = 0;

  // todo...
  ret = 1;

  return ret;
}

int
_mod_csound_play_music_file (_mod_csound_context_t * snd_context,
			     char *music_file)
{
  int ret = 0;

  // todo...
  ret = 1;

  return ret;
}

int
_mod_csound_play_music_random (_mod_csound_context_t * csound_context,
			       char *music_path, char *music_filter,
			       char *music_exclude)
{
  int ret = 0;

  // todo...
  ret = 1;

  return ret;
}

void
_mod_csound_stop_music (_mod_csound_context_t * csound_context)
{
  // todo...
}
